summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorhathach <[email protected]>2023-08-02 17:57:28 +0700
committerhathach <[email protected]>2023-08-02 17:57:28 +0700
commit2021c6299789a3dd9bd239941d9316494205fe2f (patch)
tree63149db91203c18cdd9a458d259347030654723d
parent3678a25baaeb6cd6f269d405903aeca23e93dca6 (diff)
fix pre-commit, also skip lto for rp2040
-rw-r--r--examples/host/bare_api/CMakeLists.txt2
-rw-r--r--hw/bsp/family_support.cmake4
2 files changed, 3 insertions, 3 deletions
diff --git a/examples/host/bare_api/CMakeLists.txt b/examples/host/bare_api/CMakeLists.txt
index 7049fe66b..05398b079 100644
--- a/examples/host/bare_api/CMakeLists.txt
+++ b/examples/host/bare_api/CMakeLists.txt
@@ -24,4 +24,4 @@ target_include_directories(${PROJECT} PUBLIC
# Configure compilation flags and libraries for the example without RTOS.
# See the corresponding function in hw/bsp/FAMILY/family.cmake for details.
-family_configure_host_example(${PROJECT} noos) \ No newline at end of file
+family_configure_host_example(${PROJECT} noos)
diff --git a/hw/bsp/family_support.cmake b/hw/bsp/family_support.cmake
index 9959784ae..7c230957c 100644
--- a/hw/bsp/family_support.cmake
+++ b/hw/bsp/family_support.cmake
@@ -36,8 +36,8 @@ if (NOT EXISTS ${CMAKE_CURRENT_LIST_DIR}/${FAMILY}/family.cmake)
message(FATAL_ERROR "Family '${FAMILY}' is not known/supported")
endif()
-if (NOT TINYUSB_OPT_SKIP_CHECK_IPO_SUPPORTED)
- # enable LTO if supported
+if (NOT FAMILY STREQUAL rp2040)
+ # enable LTO if supported skip rp2040
include(CheckIPOSupported)
check_ipo_supported(RESULT IPO_SUPPORTED)
if (IPO_SUPPORTED)